# Python Packing Examples

This package contains simple python scripts to count words using `Counter` collection function.

### Package Folder Structure

```
package-folder
├── LICENSE
├── README.md
├── setup.py
└── test_package
    └── __init__.py

```
